@@ -54,20 +54,27 @@
 	  (truename ".")))))
   
 (defun get-version ()
-  (let ((version ""))
-    (with-open-file (in "configure.in" :direction :input)
-      (do ((line (read-line in nil 'eof)
-		 (read-line in nil 'eof)))
-	  ((eql line 'eof))
-	(if (search "AM_INIT_AUTOMAKE" line)
-	    (progn 
-              #+openmcl (setq line (string-trim '(#\Return) line))
-	      (setf version 
-		    (replace-substring line "AM_INIT_AUTOMAKE(maxima," ""))
-	      (setf version
-		    (replace-substring version ")" ""))))))
-    version))
-  
+  (with-open-file (in "configure.ac" :direction :input)
+    (do ((line (read-line in nil 'eof)
+               (read-line in nil 'eof))
+         (version "")
+         temp)
+        ((eq line 'eof)
+         (when (string= version "")
+           (format t "WARNING: No version information found.~%~%"))
+         version)
+      (when (search "AC_INIT([maxima]," line)
+        #+openmcl (setq line (string-trim '(#\Return) line))
+        (setq temp
+              (replace-substring line "AC_INIT([maxima], [" ""))
+        (setq version
+              (replace-substring temp "])" ""))
+        (when (or (string= temp line)
+                  (string= temp version))
+          ; Failed substitution
+          (format t "WARNING: Problem parsing version information. ")
+          (format t "Found: \"~a\"~%~%" version))))))
+
 (defvar *maxima-lispname* #+clisp "clisp"
 	#+cmu "cmucl"
 	#+scl "scl"
@@ -89,7 +96,8 @@
 		  acl-name
 		  openmcl-name
 		  sbcl-name
-		  ecl-name)
+		  ecl-name
+		  gcl-name)
   (let ((prefix (if maxima-directory 
 		    maxima-directory
 		    (default-directory-string)))
@@ -102,6 +110,7 @@
 	(openmcl (if openmcl-name openmcl-name "mcl"))
 	(sbcl (if sbcl-name sbcl-name "sbcl"))
 	(ecl (if ecl-name ecl-name "ecl"))
+	(gcl (if gcl-name gcl-name "gcl"))
 	(files (list "maxima-local.in" "src/maxima.in" "src/maxima.bat.in"
 		     "src/autoconf-variables.lisp.in"))
 	(substitutions))
@@ -130,6 +139,9 @@
 	  (setf ecl 
 		(read-with-default "Name of the ECL executable (optional)"
 				   ecl))
+	  (setf gcl
+		(read-with-default "Name of the GCL executable (optional)"
+				   gcl))
 	  (setf sbcl 
 		(read-with-default "Name of the SBCL executable (optional)"
 				   sbcl))))
@@ -137,6 +149,7 @@
 				    (replace-substring prefix "\\" "\\\\"))
 			      (cons "@PACKAGE@" "maxima")
 			      (cons "@VERSION@" (get-version))
+			      (cons "@host@" "unknown")
 			      (cons "@win32@" win32-string)
 			      (cons "@default_layout_autotools@" "false")
 			      (cons "@POSIX_SHELL@" shell)
@@ -149,6 +162,7 @@
 			      (cons "@ACL_NAME@" acl)
 			      (cons "@OPENMCL_NAME@" openmcl)
 			      (cons "@ECL_NAME@" ecl)
+			      (cons "@GCL_NAME@" gcl)
 			      (cons "@SBCL_NAME@" sbcl)))
     (if verbose
 	(mapc #'(lambda (pair) (format t "~a=~a~%" (first pair) (rest pair)))
