@@ -8,39 +8,38 @@
 (in-package :maxima)
 
 (defun rational-subst (poly var denom )
-  "does a substitution like var --> var/denom  where var is a genvar 
+  "does a substitution like var --> var/denom  where var is a genvar
 and denom is a poly.  It calculates the numerator after bringing a common
 denominator of denom^(pdegree poly var)"
    (let ((deg  (pdegree poly var)))
      (setq poly (copy-tree poly))
      (sub-rat2 poly var denom deg)))
-    
 
 (cond ((not (fboundp 'p-var)) (load "msm:ratmac.fasl")))
 
-(defmacro with-main-variable ( mvar &body body)
+(defmacro with-main-variable (mvar &body body)
   `(let ((,mvar (make-symbol "zzzzzz")))
-    (set ,mvar 40000)
-    (setf (get ,mvar 'disrep) 'zzzzzzz)
-    ,@ body))
+     (setf (symbol-value ,mvar) 40000)
+     (setf (get ,mvar 'disrep) 'zzzzzzz)
+     ,@ body))
 
 (defmacro with-main  (main form-to-reorder resubstitute &body body)
   (cond ((null resubstitute)
 	 `(let ((newvar (make-symbol "zzzzzz"))
 		(oldmain ,main))
-	    (set newvar 40000)
+	    (setf (symbol-value newvar) 40000)
 	    (setq ,main newvar)
 	    (setf (get newvar 'disrep) 'zzzzzzz)
 	    (setf ,form-to-reorder (psublis (list (cons oldmain (list newvar 1 1))) 1
 					     ,form-to-reorder))
 	    (progn ,@ body)))
-	(t   
+	(t
 	 `(let ((newvar (make-symbol "zzzzzz"))
 		(oldmain ,main))
-	    (set newvar 40000)
+	    (setf (symbol-value newvar) 40000)
 	    (setq ,main newvar)
 	    (setf (get newvar 'disrep) 'zzzzzzz)
-	    (setf ,form-to-reorder 
+	    (setf ,form-to-reorder
 		  (psublis (list  (cons oldmain (list newvar 1 1))) 1
 			    ,form-to-reorder))
 	    (psublis  (list  (cons newvar (list oldmain 1 1))) 1
@@ -73,12 +72,12 @@ denominator of denom^(pdegree poly var)"
 		(replace-polynomial-coefficients
 		  degree cof poly
 		  (ptimes cof
-			  (pexpt denom (f- deg degree)))))
+			  (pexpt denom (- deg degree)))))
 	       (t
 		(setq poly
 		(sum-over-polynomial degree cof poly
 		  (ptimes (list (car poly) degree 1)
-			  (ptimes cof (pexpt denom (f- deg degree)))))))))
+			  (ptimes cof (pexpt denom (- deg degree)))))))))
 	((pointergp (car poly) var)
 	 (cond ((pointergp (car poly) (car denom))
 		(print 'a)
@@ -90,7 +89,7 @@ denominator of denom^(pdegree poly var)"
 		(sum-over-polynomial
 		  degree cof poly
 		  (ptimes (list (car poly) degree 1)
-                          (sub-rat2 cof var denom deg)))))))
+			  (sub-rat2 cof var denom deg)))))))
 	(t(setq poly (ptimes poly (pexpt denom deg)))))
   poly)
 
@@ -147,14 +146,13 @@ poly)
   "does a general sublis : a-list of form (list (cons old-var repl-poly)....)
    denom is a poly "
   (let ((tem (cond (vars-to-sub vars-to-sub)
-		   (t (sloop for v in a-list collecting (car v)))))
+		   (t (loop for v in a-list collecting (car v)))))
 	deg)
-    (cond ((polynomialp poly)
+    (cond ((affine-polynomialp poly)
 	   (cond (degree (setq deg degree))
 		 (t(setq deg (poly-degree
 			       poly
 			       tem ))))
-	   
 	   (setq answ (psublis1 a-list denom poly
 				deg
 				tem))
@@ -165,11 +163,11 @@ poly)
 				 vars-to-sub )
 			(rsublis a-list denom (denom poly) :degree degree :vars-to-sub
 				 vars-to-sub)))
-	  (t (ferror "bad type for poly : should be ratl fn or poly")))))
+	  (t (merror "bad type for poly : should be ratl fn or poly")))))
 
 (defun $psublis (a-list denom poly)
   "use psublis([y=x^2,v=u^3],denom,poly)"
-  (header-poly(psublis  (sloop for (u v  repl)  in (cdr a-list) by  'cdr
+  (header-poly(psublis  (loop for (u v  repl)  in (cdr a-list) by  #'cdr
 			      do (check-arg u (eq (car u) 'mequal) "Type a=repl")
 			      collecting
 			      (cons (p-var (st-rat v))
@@ -178,20 +176,21 @@ poly)
 
 (defun $coll_linear (expr &aux answ)
   (cond ((mbagp expr)
-	 (setq answ (sloop for v in (cdr expr) collecting (coll-linear (st-rat v)))))
+	 (setq answ (loop for v in (cdr expr) collecting (coll-linear (st-rat v)))))
 	(t (setq answ (coll-linear expr))))
   (setq answ (apply 'append answ))
-  (sloop for w in answ
+  (loop for w in answ
 	collecting (get w 'disrep) into tem
 	finally (return (cons '(mlist) tem))))
 
 (defun psubst ( repl var poly)
   (psublis (list (cons var repl)) 1 poly))
 (defun  pdiscriminant (poly var &aux main old-var answ)  ;;main variable
-   ;;change to main variable if necessary  
+   ;;change to main variable if necessary
   (cond ((eq var :main)(setq var (p-var poly)))
 	((not (eql var (p-var poly)))
-	 (setq main (gensym))(set main 40000000)
+	 (setq main (gensym))
+	 (setf (symbol-value main) 40000000)
 	 (setf (get main 'disrep) 'main-var)
 	 (show main)(setq old-var var)
 	 (setq poly (psubst (list main 1 1) var poly))
@@ -214,40 +213,38 @@ poly)
 
 
 
-;;incorrect needs 
+;;incorrect needs
 (defun gen-vrem (b divisor &aux tem)
-  (cond 
-    ((atom divisor) 0)		
+  (cond
+    ((atom divisor) 0)
     ((atom b)b )
     ((pointergp (p-var divisor) (p-var b))
      b)
     ((eq (p-var divisor) (p-var b))
 	 (second (vdivide b divisor)))
     ((pointergp (p-var b) (p-var divisor))
-     (sloop for (deg cof) on (cdr b) by 'cddr
+     (loop for (deg cof) on (cdr b) by #'cddr
 	   do (setq tem (gen-vrem  cof divisor))
 	   when (not  (pzerop  tem))
 	   collecting deg into lis
 	   collecting tem into lis
-	   finally (return (cond ( (eq (car lis) 0)
-				  (second lis))
-
-
+	   finally (return (cond ((eq (car lis) 0) (second lis))
  				 (t (cons (p-var b) lis))))))))
+
 ;;incorrect doesn't take into account the
 ;;denoms eg z^3+ z*p1(x) +p2(x) must find the c for p1 and for p2 and then mult
 ;;up appropriateley.
-;;won't work for x^2*y+x+1 where  
+;;won't work for x^2*y+x+1 where
 (defun gen-vrem (b divisor &aux tem)
-  (cond 
-    ((atom divisor) 0)		
+  (cond
+    ((atom divisor) 0)
     ((atom b)b )
     ((pointergp (p-var divisor) (p-var b))
      b)
     ((eq (p-var divisor) (p-var b))
 	 (second (vdivide b divisor)))
     ((pointergp (p-var b) (p-var divisor))
-     (sloop for (deg cof) on (cdr b) by 'cddr
+     (loop for (deg cof) on (cdr b) by #'cddr
 	   do (setq tem (gen-vrem  cof divisor))
 	   when (not  (pzerop  tem))
 	   collecting deg into lis
@@ -258,8 +255,8 @@ poly)
 
 ;;for resubstitute = nil then we would not want to
 ;(defun pdeg (pol var)
-;  (with-main var pol t				
-;     (print    (second pol))(print var) pol)) 
+;  (with-main var pol t
+;     (print    (second pol))(print var) pol))
 ;
 ;(defun pdeg (pol var)
 ;  (with-main var pol nil
@@ -270,21 +267,18 @@ poly)
 
 (defun highest-power-dividing (f divisor &aux quot )
 ;  (declare (values power final-quotient))
-  (sloop for i from 1
+  (loop for i from 1
 	with prev-quot = f
-	do 
-	
-	(setq quot       (testdivide prev-quot divisor))
+	do
+	(setq quot (testdivide prev-quot divisor))
 	when (null quot)
-	do (return (values (f1- i) prev-quot))
+	do (return (values (1- i) prev-quot))
 	else do (setq prev-quot quot)))
 
 ;c-reqd*f=g*quot+remaind
 (defun gen-prem (f g var &aux remainder c-reqd)
   (cond ((< (pdegree f var) (pdegree g var))
-	 
 	 (setq remainder f)(setq c-reqd 1))
-
 	(t
 	 (cond ((and (eq (p-var f) (p-var g))
 		     (eq (p-var f) var))
@@ -313,18 +307,18 @@ poly)
 ;  (setq dis (new-disrep ans2))
 ;;  (setq dis ($totaldisrep (header-poly ans2)))
 ;   (list '(mlist) ans1 dis ($ratsimp (sub* ans1 dis))))
-						
+
 ;;works now c*b=q*divisor +r
 (defun vdivide (b divisor &aux rnew rfactor leading-gcd deltaq)
-  (let ((q 0)(c 1)(r  b)) 
-    (cond 
+  (let ((q 0)(c 1)(r  b))
+    (cond
       ((atom divisor) (list b 0 divisor)) ;;should b/gcd(c(b),divisor) 0 a/same
       ((atom b) (list 0 b 1))
       ((pointergp (p-var divisor) (p-var b))
        (list 0 b 1))
       ((pointergp (p-var b) (p-var divisor))
        (list b 0 divisor))
-      (t (sloop until (or (atom r)
+      (t (loop until (or (atom r)
 			 (not (eql (p-var r) (p-var divisor)))
 			 (< (p-le r) (p-le divisor)))
 	       with mon = (list (p-var r) 1 1)
@@ -341,9 +335,9 @@ poly)
 	       ;;then multiply by (p-var r)^ m where m=(differenc of leading degrees)
 	       (setq deltaq (ptimes (pquotient (p-lc r) leading-gcd)
 				    (pexpt mon (- (p-le r) (p-le divisor)))))
-; 	       (mshow  rnew divisor (p-lc rnew) (p-lc divisor) deltaq)              
+; 	       (mshow  rnew divisor (p-lc rnew) (p-lc divisor) deltaq)
 
-;	       (setq prev-rdeg (p-le r))      
+;	       (setq prev-rdeg (p-le r))
 	       (setq r (pdifference rnew
 				    (ptimes divisor
 					    deltaq)))
@@ -351,12 +345,12 @@ poly)
 ;	       (cond ((not (< (p-le r) prev-rdeg)) (break t)))
 	       (setq q (pplus (ptimes rfactor q) deltaq))
 	       finally (return (list q r c)))))))
-	    
 
 
-  
+
+
 ;(defmacro mshow (&rest l)
-;  (sloop for v in l
+;  (loop for v in l
 ;	collecting `(format t "~%The value of ~A is.. " ',v) into tem
 ;	collecting `(sh ,v) into tem
 ;	finally (return (cons 'progn tem))))
@@ -365,7 +359,7 @@ poly)
 ;  (let ((answ (vdivide b divisor)))
 ;    (pdifference (ptimes (third answ) b)
 ;		 (pplus (ptimes (first answ) a)
-;	                (second answ)))))
+;			(second answ)))))
 
 (defun coll-linear  (f &aux *linear*)
 	(declare (special *linear*))
@@ -379,7 +373,7 @@ poly)
 			((null tail) t)
 		      (cond ((null (constant-polyp (cadr f)))
 			     (return nil)))))))))
-		  
+
 ;;checked thisn
 (defun coll-linear1 (poly)
   (declare (special *non-linear*))
@@ -387,27 +381,25 @@ poly)
   ;;here we collect things that look linear but u*z+u  would collect u
   (cond ((atom poly) nil)
 	((get (car poly) 'constant)
-	 (sloop for (deg cof) on (cdr poly) by 'cddr
-	       do     (coll-linear1 cof)))
+	 (loop for (deg cof) on (cdr poly) by #'cddr
+	       do (coll-linear1 cof)))
 	(t (cond ((and (eq (p-le poly) 1)
 		       (constant-functionp (p-lc poly)))
-		  
-		  (push-new (p-var poly) *linear*)))
-	   (cond ((eq 0 (nth (f- (length poly)  2) poly))
+		  (pushnew (p-var poly) *linear*)))
+	   (cond ((eq 0 (nth (- (length poly)  2) poly))
 		  (coll-linear1 (car (last poly)))))))
   ;;now must check these are really linear to remove the u collected above.
   (cond ((consp poly)
 	 (let ((ldeg 0))
 	 (cond ((get (p-var poly) 'constant)(setq ldeg 1)))
-	       
-	 (sloop for u in *linear*
+	 (loop for u in *linear*
 	       do
-	 (sloop for (deg cof) on  (cdr poly) by 'cddr while
+	 (loop for (deg cof) on  (cdr poly) by 'cddr while
 	       (> deg 0)
 	       when (> (pdegree cof u) ldeg)
 	       do  (setq *linear* (delete u *linear* :test #'equal)))))))
   )
-	
+
 ;(compare-functions
 
 (defun gen-psublis (old new poly)
@@ -416,70 +408,62 @@ poly)
     (psublis subs denom poly)))
 
 (defun gen-rat-sublis (old new f &optional (switch t) &aux answ)
- (simple-rat-sublis (subs-for-simple-rat-sublis old new) f))
+  (simple-rat-sublis (subs-for-simple-rat-sublis old new) f))
 
-
-(defun subs-for-psublis (old new &optional &aux   (lcd 1) a-denom)
+(defun subs-for-psublis (old new &optional &aux (lcd 1) a-denom)
   (cond (($listp old) (setq old (cdr old))))
   (cond (($listp new) (setq new (cdr new))))
-  (sloop for v in old when  (not (get v 'disrep))
-	do (return (sloop for v in old
-			 when (not (get v 'disrep ))
-                         do (cond ((symbolp v)
-				   (setq v (add-newvar v)))
-				  
-				  (t (ferror "only for replacing symbols")))
-			 collecting v into tem
-			 finally (setq old tem))))
-  (setq new (sloop for v in new
-		   when (symbolp v)
-		   do (cond ((get v 'disrep)
-			     (setq v (list v 1 1)))
-			    (t (setq v (st-rat v))))
-		   else when (polynomialp v) do nil
-		   else do (setq v (new-rat v)) (setq a-denom t)
-		   (setq lcd (plcm lcd (denom v)))
-		   collecting v))
+  (loop for v in old when  (not (get v 'disrep))
+     do (return (loop for v in old
+		   when (not (get v 'disrep ))
+		   do (cond ((symbolp v)
+			     (setq v (add-newvar v)))
+			    (t (merror "only for replacing symbols")))
+		   collecting v into tem
+		   finally (setq old tem))))
+  (setq new (loop for v in new
+	       when (symbolp v)
+	       do (cond ((get v 'disrep)
+			 (setq v (list v 1 1)))
+			(t (setq v (st-rat v))))
+	       else when (affine-polynomialp v) nconc nil
+	       else do (setq v (new-rat v)) (setq a-denom t)
+		 (setq lcd (plcm lcd (denom v)))
+	       collecting v))
   (cond (a-denom
-	 (sloop for v on new
-	       when (polynomialp (car v)) do (setf (car v)
-						   (gen-ptimes lcd (car v)))
-	       else
-	       do (setf (car v) (gen-ptimes
-				  (num (car v)) (pquotient lcd (denom (car v)))))))
+	 (loop for v on new
+	    when (affine-polynomialp (car v)) do (setf (car v)	(gen-ptimes lcd (car v)))
+	    else
+	    do (setf (car v) (gen-ptimes (num (car v)) (pquotient lcd (denom (car v)))))))
 	(t (setq new (subseq new 0 (length old)))))
-  (sloop for v in old
-	for w on new
-	do (setf (car w)
-		 (cons v (car w))))
+  (loop for v in old
+     for w on new
+     do (setf (car w) (cons v (car w))))
   (values new lcd))
 
-
-
 (defun simple-rat-sublis ( subs f &optional (switch t) &aux sub)
   (cond ((atom f) (cons f 1))
 	((and (numberp (car f))(numberp (cdr f))) f)
-	((polynomialp f)
-	 (setq sub (cdr (assoc  (p-var f :test #'equal) subs)))
+	((affine-polynomialp f)
+	 (setq sub (cdr (assoc (p-var f) subs :test #'equal)))
 	 (cond ((null sub)(setq sub (cons  (list  (p-var f) 1 1) 1))))
-	 (sloop for ( deg cof) on (cdr f) by 'cddr
+	 (loop for (deg cof) on (cdr f) by #'cddr
 	       with answ = (cons 0 1)
 	       do (setq answ (ratplus answ (rattimes (ratexpt sub deg)
-						     (simple-rat-sublis subs
-									cof) switch)))
+						     (simple-rat-sublis subs cof) switch)))
 	       finally (return answ)))
 	((rational-functionp f)
 	 (ratquotient (simple-rat-sublis subs (num  f) switch)
 	       (simple-rat-sublis subs (denom  f) switch)))
-	((sloop for v in f collecting (simple-rat-sublis subs v switch)))))
+	((loop for v in f collecting (simple-rat-sublis subs v switch)))))
+
 
- 
 (defun subs-for-simple-rat-sublis (varl subs)
-  (sloop for v in varl
+  (loop for v in varl
 	for w in subs
 	when (not  (get v 'disrep))
 	do (setq v (add-newvar v))
-	do (cond ((polynomialp w)
+	do (cond ((affine-polynomialp w)
 		  (setq w (cons w 1)))
 		 ((rational-functionp w) nil)
 		 ((get w 'disrep)(setq w (cons (list w 1 1)1)))
@@ -491,7 +475,7 @@ poly)
 
 (defun gen-rat-sublis (old new f &optional (switch t) &aux )
    (simple-rat-sublis (subs-for-simple-rat-sublis old new) f))
-  
+
 ;
 ;;;I tested it on a number of fns and it worked.
 ;(defun test (old new fn)
@@ -502,10 +486,10 @@ poly)
 ;  (equal ans1 ans2))
 
 (defun collect-monomial-coefficients (poly variables)
-  "Returns a list of all coefficients of all monomials in VARIABLES occurring in POLY" 
+  "Returns a list of all coefficients of all monomials in VARIABLES occurring in POLY"
   (cond ((null variables) (list poly))
 	(($zerop poly) (list poly))
-	(t (sloop for i from 0 to (pdegree poly (car variables))
+	(t (loop for i from 0 to (pdegree poly (car variables))
 		 when (>= i  1)
 		 appending (collect-monomial-coefficients
 			     (pcoeff poly (list (car variables) i 1)) (cdr variables))
@@ -521,7 +505,7 @@ poly)
    then verifies it has the whole sum"
 
   (cond ((null variables) (list (list monomial poly)))
-	(t (sloop for i from 0 to (pdegree poly (car variables))
+	(t (loop for i from 0 to (pdegree poly (car variables))
 		 for mon = (list (car variables) i 1)
 		 when (>= i  1)
 		 appending (collect-monomial-coefficients-and-monomials
@@ -536,7 +520,7 @@ poly)
 
 (defun collect-and-verify-coefficients (poly variables &aux answ)
   (setq answ (collect-monomial-coefficients-and-monomials poly variables))
-  (sloop for v in answ
+  (loop for v in answ
 	with answer = 0
 	do (setq answer (pplus answer (ptimes (first v) (second v))))
 	finally (iassert (equal answer poly))
@@ -544,4 +528,3 @@ poly)
 
 (defun va (h)
   (list-variables  (st-rat h)))
-
