@@ -3,7 +3,7 @@
 ;;;;
 ;;;;  Maxima string processing
 ;;;;
-;;;;  Copyright     : 2005-2014 Volker van Nek
+;;;;  Copyright     : 2005-2015 Volker van Nek
 ;;;;  Licence       : GPL2
 ;;;;
 ;;;;  Test file     : rteststringproc.mac
@@ -21,6 +21,10 @@
 ;;  1. I/O
 
 
+;; $openw_binary, $opena_binary, $openr_binary 
+;;    are placed in share/numercalio/numercalio.lisp.
+
+
 (defun $openw (file)
   (if (not (stringp file))
     (merror "openw: argument must be a path string."))
@@ -73,6 +77,12 @@
   (close stream))
 
 
+(defun $flush_output (stream) 
+  (unless (streamp stream)
+    (merror (intl:gettext "flush_output: argument must be a stream.")) )
+  (not (finish-output stream)) ) ;; so $flush_output and $close both return t
+
+
 (defun $flength (stream) 
   (if (not (streamp stream))
     (merror "flength: argument must be a stream."))
@@ -105,6 +115,20 @@
     (when lc (m-char lc)) ))
 
 
+(defun $readbyte (stream) 
+  (unless (and (streamp stream)
+               (equal (stream-element-type stream) '(unsigned-byte 8)) )
+    (merror (intl:gettext "readbyte: argument must be a binary stream.")) )
+  (read-byte stream nil nil) )
+
+
+(defun $writebyte (i stream) 
+  (unless (and (streamp stream)
+               (equal (stream-element-type stream) '(unsigned-byte 8)) )
+    (merror (intl:gettext "writebyte: argument must be a binary stream.")) )
+  (write-byte i stream) )
+
+
 (defun $freshline (&optional (stream)) 
   (and stream (not (streamp stream))
     (merror "freshline: optional argument must be a stream."))
