@@ -1068,10 +1068,18 @@
        (simp-domain-error 
          (intl:gettext "expintegral_ei: expintegral_ei(~:M) is undefined.") 
          arg))
-      ((eq arg '$inf) '$inf)
-      ((or (eq arg '$minf) (alike1 arg '((mtimes) -1 $inf))) 0)
-      ((alike1 arg '((mtimes) $%i $inf)) (mul '$%i '$%pi))
-      ((alike1 arg '((mtimes) -1 $%i $inf)) (mul -1 '$%i '$%pi))
+      ((or (eq arg '$inf)
+           (alike1 arg '((mtimes) -1 $minf)))
+       '$inf)
+      ((or (eq arg '$minf)
+           (alike1 arg '((mtimes) -1 $inf)))
+       0)
+      ((or (alike1 arg '((mtimes) $%i $inf))
+           (alike1 arg '((mtimes) -1 $%i $minf)))
+       (mul '$%i '$%pi))
+      ((or (alike1 arg '((mtimes) $%i $minf))
+           (alike1 arg '((mtimes) -1 $%i $inf)))
+       (mul -1 '$%i '$%pi))
 
       ;; Check numerical evaluation
       ((complex-float-numerical-eval-p arg)
@@ -1253,7 +1261,9 @@
       ((onep1 arg)
        (simp-domain-error
 	(intl:gettext "expintegral_li: expintegral_li(~:M) is undefined.") arg))
-      ((eq arg '$inf) '$inf)
+      ((or (eq arg '$inf)
+           (alike1 arg '((mtimes) -1 $minf)))
+       '$inf)
       ((eq arg '$infinity) '$infinity)
 
       ((complex-float-numerical-eval-p arg)
@@ -1372,6 +1382,18 @@
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
+;;; We support a simplim%function.
+
+(defprop %expintegral_si simplim%expintegral_si simplim%function)
+
+(defun simplim%expintegral_si (expr var val)
+  ;; Look for the limit of the argument.
+  (let ((z (limit (cadr expr) var val 'think)))
+    ;; All cases are handled by the simplifier of the function.
+    (take '(%expintegral_si) z)))
+
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
 (defun simp-expintegral-si (expr ignored z)
   (declare (ignore ignored))
   (oneargcheck expr)
@@ -1379,9 +1401,12 @@
     (cond
       ;; Check for special values
       ((zerop1 arg) arg)
-      ((eq arg '$inf) (div '$%pi 2))
-      ((eq arg '$minf) (mul -1 (div '$%pi 2)))
-      ((alike1 arg '((mtimes) -1 $inf)) (mul -1 (div '$%pi 2)))
+      ((or (eq arg '$inf)
+           (alike1 arg '((mtimes) -1 $minf)))
+       (div '$%pi 2))
+      ((or (eq arg '$minf)
+           (alike1 arg '((mtimes) -1 $inf)))
+       (mul -1 (div '$%pi 2)))
 
       ;; Check for numerical evaluation     
       ((complex-float-numerical-eval-p arg)
@@ -1521,6 +1546,26 @@
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
+;;; We support a simplim%function. The function is looked up in simplimit and 
+;;; handles specific values of the function.
+
+(defprop %expintegral_shi simplim%expintegral_shi simplim%function)
+
+(defun simplim%expintegral_shi (expr var val)
+  ;; Look for the limit of the argument.
+  (let ((z (limit (cadr expr) var val 'think)))
+    (cond
+      ;; Handle infinities at this place
+      ((eq z '$inf)
+       '$inf)
+      ((eq z '$minf)
+       '$minf)
+      (t
+       ;; All other cases are handled by the simplifier of the function.
+       (take '(%expintegral_shi) z)))))
+
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
 (defun simp-expintegral-shi (expr ignored z)
   (declare (ignore ignored))
   (oneargcheck expr)
@@ -1528,8 +1573,12 @@
     (cond
       ;; Check for special values
       ((zerop1 arg) arg)
-      ((alike1 arg '((mtimes) '$%i $inf)) (div (mul '$%i '$%pi) 2))
-      ((alike1 arg '((mtimes) -1 '$%i $inf)) (div (mul -1 '$%i '$%pi) 2))
+      ((or (alike1 arg '((mtimes) $%i $inf))
+           (alike1 arg '((mtimes) -1 $%i $minf)))
+       (div (mul '$%i '$%pi) 2))
+      ((or (alike1 arg '((mtimes) $%i $minf))
+           (alike1 arg '((mtimes) -1 $%i $inf)))
+       (div (mul -1 '$%i '$%pi) 2))
 
       ;; Check for numrical evaluation
       ((float-numerical-eval-p arg)
@@ -1702,9 +1751,12 @@
       ((zerop1 arg)
        (simp-domain-error
 	(intl:gettext "expintegral_ci: expintegral_ci(~:M) is undefined.") arg))
-      ((eq arg '$inf) 0)
-      ((eq arg '$minf) (mul '$%i '$%pi))
-      ((alike1 arg '((mtimes) -1 $inf)) (mul '$%pi '$%pi))
+      ((or (eq arg '$inf)
+           (alike1 arg '((mtimes) -1 $minf)))
+       0)
+      ((or (eq arg '$minf)
+           (alike1 arg '((mtimes) -1 $inf)))
+       (mul '$%i '$%pi))
 
       ;; Check for numerical evaluation
       ((complex-float-numerical-eval-p arg)
@@ -1869,6 +1921,9 @@
          (eq z '$zeroa)
          (eq z '$zerob))
      '$minf)
+    ((or (eq z '$inf)
+         (eq z '$minf))
+     '$inf)
     (t
      ;; All other cases are handled by the simplifier of the function.
      (take '(%expintegral_chi) z)))))
@@ -1886,8 +1941,12 @@
        (simp-domain-error
 	(intl:gettext "expintegral_chi: expintegral_chi(~:M) is undefined.") 
         arg))
-      ((alike1 arg '((mtimes) $%i $inf)) (div (mul '$%pi '$%i) 2))
-      ((alike1 arg '((mtimes) -1 $%i $inf)) (div (mul -1 '$%pi '$%i) 2))
+      ((or (alike1 arg '((mtimes) $%i $inf))
+           (alike1 arg '((mtimes) -1 $%i $minf)))
+       (div (mul '$%pi '$%i) 2))
+      ((or (alike1 arg '((mtimes) $%i $minf))
+           (alike1 arg '((mtimes) -1 $%i $inf)))
+       (div (mul -1 '$%pi '$%i) 2))
 
       ;; Check for numerical evaluation
       ((complex-float-numerical-eval-p arg)
