@@ -136,7 +136,7 @@ When one changes, the other does too."
 	  (setq libdir     (combine-path maxima-prefix-env "lib"))
 	  (setq libexecdir (combine-path maxima-prefix-env "libexec"))
 	  (setq datadir    (combine-path maxima-prefix-env "share"))
-	  (setq infodir    (combine-path maxima-prefix-env "info")))
+	  (setq infodir    (combine-path maxima-prefix-env #+(or cygwin windows win32) "share" "info")))
 	(progn
 	  (setq libdir     (maxima-parse-dirstring *autoconf-libdir*))
 	  (setq libexecdir (maxima-parse-dirstring *autoconf-libexecdir*))
@@ -237,6 +237,14 @@ When one changes, the other does too."
 				(setq *maxima-lang-subdir* (concatenate 'string *maxima-lang-subdir* ".koi8r")))))
 			(t  (setq *maxima-lang-subdir* nil))))))))
 
+(flet ((sanitize-string (s)
+	 (map 'string (lambda(x) (if (alphanumericp x) x #\_))
+	      (subseq s 0 (min 142 (length s))))))
+  (defun lisp-implementation-version1 ()
+    (sanitize-string (lisp-implementation-version)))
+  (defun maxima-version1 ()
+    (sanitize-string *autoconf-version*)))
+
 (defun set-pathnames ()
   (let ((maxima-prefix-env (maxima-getenv "MAXIMA_PREFIX"))
 	(maxima-layout-autotools-env (maxima-getenv "MAXIMA_LAYOUT_AUTOTOOLS"))
@@ -272,7 +280,7 @@ When one changes, the other does too."
                        (if maxima-objdir-env
                          (maxima-parse-dirstring maxima-objdir-env)
                          (concatenate 'string *maxima-userdir* "/binary"))
-                       "/binary-" *maxima-lispname*))
+                       "/" (maxima-version1) "/" *maxima-lispname* "/" (lisp-implementation-version1)))
 
     ; On Windows Vista gcc requires explicit include
     #+gcl
@@ -501,7 +509,8 @@ When one changes, the other does too."
 			   :argument "<port>"
 			   :action #'(lambda (port-string)
 				       (start-client (parse-integer
-						      port-string)))
+						      port-string))
+                                       (setf input-stream *standard-input*))
 			   :help-string "Connect Maxima to server on <port>.")
 	   (make-cl-option :names '("-u" "--use-version")
 			   :argument "<version>"
@@ -578,7 +587,8 @@ When one changes, the other does too."
   (set-locale-subdir)
   (adjust-character-encoding)
   (set-pathnames)
-  (cl-info::load-primary-index)   
+  (catch 'return-from-debugger
+    (cl-info::load-primary-index))
   (when (boundp '*maxima-prefix*)
     (push (pathname (concatenate 'string *maxima-prefix*
                                  (if *maxima-layout-autotools*
@@ -675,5 +685,6 @@ When one changes, the other does too."
 ;; usable *LOAD-PATHNAME*, but it does have SYS:*LOAD-PATHNAME*.
 (defun maxima-load-pathname-directory ()
   "Return the directory part of *load-pathname*."
-  (make-pathname :directory (pathname-directory #-gcl *load-pathname*
-						#+gcl sys:*load-pathname*)))
+  (let ((path *load-pathname*))
+    (make-pathname :directory (pathname-directory path)
+                   :device (pathname-device path))))
