@@ -101,6 +101,7 @@
 
 (dolist (f       
      '($close
+       $flush_output
        $flength
        $fposition
        $freshline
@@ -113,6 +114,8 @@
        $get_output_stream_string
        $printf
        $sprint
+       $writebyte
+       $readbyte
        $readchar
        $readline
        $alphacharp
@@ -133,19 +136,15 @@
        $lowercasep
        $uppercasep
        $stringp
-       $base64
-       $base64_decode
        $charat
        $charlist
        $eval_string
-       $md5sum
        $parse_string
        $scopy
        $sdowncase
        $sequal
        $sequalignore
        $sexplode
-       $sha1sum
        $simplode
        $sinsert
        $sinvertcase
@@ -167,7 +166,17 @@
        $substring
        $supcase
        $tab
-       $tokens ))
+       $tokens
+       $base64
+       $base64_decode
+       $crc24sum
+       $md5sum
+       $number_to_octets
+       $octets_to_number
+       $octets_to_oid
+       $oid_to_octets
+       $sha1sum
+       $sha256sum ))
   (setf (get f 'autoload) "stringproc"))
 
 
@@ -192,8 +201,16 @@
     $write_data))
   (setf (get f 'autoload) "numericalio"))
 
-(setf (get '$eval_string 'autoload) "eval_string")
-(setf (get '$parse_string 'autoload) "eval_string")
+(dolist (f       
+  '($bit_and
+    $bit_length
+    $bit_lsh
+    $bit_not
+    $bit_onep
+    $bit_or
+    $bit_rsh
+    $bit_xor ))
+  (setf (get f 'autoload) "bitwise"))
 
 
 ;; functions from share/linearalgebra 
@@ -225,6 +242,7 @@
        $zeromatrixp
        
        $get_lu_factors         ; lu.lisp
+       $determinant_by_lu 
        $invert_by_lu 
        $linsolve_by_lu
        $lu_backsub
