@@ -179,7 +179,6 @@
 
 ;; These following functions, when they are the value of *break-step*
 ;; are invoked by an inner hook in eval. They may choose to stop things.
-(defvar *break-step* nil)
 (defun break-step-into (form &optional env)
   (let ((fun (current-step-fun)))
     (let ((line-info (set-full-lineinfo fun)))
@@ -405,8 +404,8 @@
       (catch *quit-tag*
 	(unwind-protect
 	     (do () (())
-	       (format-prompt *debug-io* "~a"
-			      (format nil "~&~@[(~a:~a) ~]"
+	       (format-prompt *debug-io* "~&~a"
+			      (format nil "~@[(~a:~a) ~]"
 				      (unless (stringp at) "dbm")
 				      (length *quit-tags*)))
 	       (finish-output *debug-io*)
@@ -650,7 +649,8 @@ Command      Description~%~
 
 (defmacro lisp-quiet (&rest l)
   (setq *mread-prompt* "")
-  (eval (cons 'progn l)))
+  (eval (cons 'progn l))
+  nil)
 
 (def-break :lisp-quiet 'lisp-quiet 
   "Evaluate the lisp form without printing a prompt")
