@@ -25,17 +25,17 @@
 
 (eval-when #-gcl(:compile-toplevel :load-toplevel :execute) 
 	   #+gcl(load compile eval)
-	   (defpackage "MAXIMA-NREGEX"
-	     (:use "COMMON-LISP")
+	   (defpackage :maxima-nregex
+	     (:use :common-lisp)
 	     (:export
 	      ;; Vars
-	      "*REGEX-DEBUG*" "*REGEX-GROUPS*" "*REGEX-GROUPINGS*"
+	      #:*regex-debug* #:*regex-groups* #:*regex-groupings*
 	      ;; Functions
-	      "REGEX-COMPILE"
+	      #:regex-compile
 	      ))
 	   )
 
-(in-package "MAXIMA-NREGEX")
+(in-package :maxima-nregex)
 
 (eval-when (:compile-toplevel :load-toplevel :execute)
   (defvar *regex-debug* nil)	    ; Set to nil for no debugging code
@@ -236,7 +236,7 @@
 			   (not (eql (char source (+ x 2)) #\])))
 		      (if (>= (char-code (char source x))
 			      (char-code (char source (+ 2 x))))
-			  (error "Invalid range \"~A-~A\".  Ranges must be in acending order"
+			  (error (intl:gettext "regex: ranges must be in acending order; found: \"~A-~A\"")
 				 (char source x) (char source (+ 2 x))))
 		      (do ((j (char-code (char source x)) (1+ j)))
 			  ((> j (char-code (char source (+ 2 x))))
