@@ -963,8 +963,7 @@
   "The first argument is some location holding a number. This number is
   incremented by the second argument, DELTA, which defaults to 1."
   (multiple-value-bind (dummies vals newval setter getter)
-      (#-gcl get-setf-expansion #+gcl get-setf-method
-	     place env)
+      (get-setf-expansion place env)
     (let ((d (gensym)))
       `(let* (,@(mapcar #'list dummies vals)
               (,d ,delta)
@@ -975,8 +974,7 @@
   "The first argument is some location holding a number. This number is
   decremented by the second argument, DELTA, which defaults to 1."
   (multiple-value-bind (dummies vals newval setter getter)
-      (#-gcl get-setf-expansion #+gcl get-setf-method
-	     place env)
+      (get-setf-expansion place env)
     (let ((d (gensym)))
       `(let* (,@(mapcar #'list dummies vals)
               (,d ,delta)
@@ -2071,21 +2069,18 @@
 ;;;   Return a value of pi with the same precision as the argument.
 ;;; For rationals, we return a single-float approximation.
 (defmethod %pi ((x cl:rational))
-  (declare (ignore x))
   (cl:coerce cl:pi 'single-float))
 
 (defmethod %pi ((x cl:float))
   (cl:float cl:pi x))
 
 (defmethod %pi ((x bigfloat))
-  (declare (ignore x))
   (to (maxima::bcons (maxima::fppi))))
 
 (defmethod %pi ((x cl:complex))
   (cl:float cl:pi (realpart x)))
 
 (defmethod %pi ((x complex-bigfloat))
-  (declare (ignore x))
   (to (maxima::bcons (maxima::fppi))))
 
 ;;; %e - External
@@ -2093,21 +2088,18 @@
 ;;;   Return a value of e with the same precision as the argument.
 ;;;   For rationals, we return a single-float approximation.
 (defmethod %e ((x cl:rational))
-  (declare (ignore x))
   (cl:coerce maxima::%e-val 'single-float))
 
 (defmethod %e ((x cl:float))
   (cl:float maxima::%e-val x))
 
 (defmethod %e ((x bigfloat))
-  (declare (ignore x))
   (to (maxima::bcons (maxima::fpe))))
 
 (defmethod %e ((x cl:complex))
   (cl:float maxima::%e-val (realpart x)))
 
 (defmethod %e ((x complex-bigfloat))
-  (declare (ignore x))
   (to (maxima::bcons (maxima::fpe))))
 
 ;;;; Useful routines
@@ -2211,3 +2203,238 @@
 	  sum)
       #+nil
       (format t "~4d: ~S ~S ~S~%" k sum term (funcall f k)))))
+
+;; Format bigfloats using ~E format. This is suitable as a ~// format.
+;;
+;; NOTE: This is a modified version of FORMAT-EXPONENTIAL from CMUCL to
+;; support printing of bfloats.
+
+(defun format-e (stream number colonp atp
+		 &optional w d e k
+		   overflowchar padchar exponentchar)
+  (typecase number
+    (bigfloat
+     (maxima::bfloat-format-e stream (real-value number) colonp atp
+			      w d e (or k 1)
+			      overflowchar
+			      (or padchar #\space)
+			      (or exponentchar #\b)))
+    (complex-bigfloat
+     ;; FIXME: Do something better than this since this doesn't honor
+     ;; any of the parameters.
+     (princ number stream))
+    (otherwise
+     ;; We were given some other kind of object. Just use CL's normal
+     ;; ~E printer to print it.
+     (let ((f
+	     (with-output-to-string (s)
+	       ;; Construct a suitable ~E format string from the given
+	       ;; parameters. First, handle w,d,e,k.
+	       (write-string "~V,V,V,V," s)
+	       (if overflowchar
+		   (format s "'~C," overflowchar)
+		   (write-string "," s))
+	       (if padchar
+		   (format s "'~C," padchar)
+		   (write-string "," s))
+	       (when exponentchar
+		 (format s "'~C" exponentchar))
+	       (when colonp
+		 (write-char #\: s))
+	       (when atp
+		 (write-char #\@ s))
+	       (write-char #\E s))))
+       (format stream f w d e k number)))))
+
+#|
+(defmacro assert-equal (expected form)
+  (let ((result (gensym))
+	(e (gensym)))
+    `(let ((,e ,expected)
+	  (,result ,form))
+       (unless (equal ,e ,result)
+	 (format *debug-io* "Assertion failed: Expected ~S but got ~S~%" ,e ,result)))))
+
+(assert-equal "  0.990E+00" (format nil
+				    "~11,3,2,0,'*,,'E/bigfloat::format-e/"
+				    (bigfloat:bigfloat 99/100)))
+(assert-equal "  0.999E+00" (format nil
+				    "~11,3,2,0,'*,,'E/bigfloat::format-e/"
+				    (bigfloat:bigfloat 999/1000)))
+;; Actually "  0.100E+01", but format-e doesn't round the output.
+(assert-equal "  0.999E+00" (format nil
+				    "~11,3,2,0,'*,,'E/bigfloat::format-e/"
+				    (bigfloat:bigfloat 9999/10000)))
+(assert-equal "  0.999E-04" (format nil
+				    "~11,3,2,0,'*,,'E/bigfloat::format-e/"
+				    (bigfloat:bigfloat 0000999/10000000)))
+;; Actually "  0.100E-03", but format-e doesn't round the output.
+(assert-equal "  0.999E-0e" (format nil
+				    "~11,3,2,0,'*,,'E/bigfloat::format-e/"
+				    (bigfloat:bigfloat 00009999/100000000)))
+(assert-equal "  9.999E-05" (format nil
+				    "~11,3,2,,'*,,'E/bigfloat::format-e/"
+				    (bigfloat:bigfloat 00009999/100000000)))
+;; Actually "  1.000E-04", but format-e doesn't round the output.
+(assert-equal "  9.999E-05" (format nil
+				    "~11,3,2,,'*,,'E/bigfloat::format-e/"
+				    (bigfloat:bigfloat 000099999/1000000000)))
+;; All of these currently fail.
+(assert-equal ".00123d+6" (format nil
+				  "~9,,,-2/bigfloat::format-e/"
+				  (bigfloat:bigfloat 1.2345689d3)))
+(assert-equal "-.0012d+6" (format nil
+				  "~9,,,-2/bigfloat::format-e/"
+				  (bigfloat:bigfloat -1.2345689d3)))
+(assert-equal ".00123d+0" (format nil
+				  "~9,,,-2/bigfloat::format-e/"
+				  (bigfloat:bigfloat 1.2345689d-3)))
+(assert-equal "-.0012d+0" (format nil
+				  "~9,,,-2/bigfloat::format-e/"
+				  (bigfloat:bigfloat -1.2345689d-3)))
+
+;; These fail because too many digits are printed and because the
+;; scale factor isn't properly applied.
+(assert-equal ".00000003d+8" (format nil
+				     "~9,4,,-7E"
+				     (bigfloat:bigfloat pi)))
+(assert-equal ".000003d+6" (format nil
+				   "~9,4,,-5E"
+				   (bigfloat:bigfloat pi)))
+(assert-equal "3141600.d-6" (format nil
+				    "~5,4,,7E"
+				    (bigfloat:bigfloat pi)))
+(assert-equal "  314.16d-2" (format nil
+				    "~11,4,,3E"
+				    (bigfloat:bigfloat pi)))
+(assert-equal "  31416.d-4" (format nil
+				    "~11,4,,5E"
+				    (bigfloat:bigfloat pi)))
+(assert-equal "  0.3142d+1" (format nil
+				    "~11,4,,0E"
+				    (bigfloat:bigfloat pi)))
+(assert-equal ".03142d+2" (format nil
+				  "~9,,,-1E"
+				  (bigfloat:bigfloat pi)))
+(assert-equal "0.003141592653589793d+3" (format nil
+						"~,,,-2E"
+						(bigfloat:bigfloat pi)))
+(assert-equal "31.41592653589793d-1" (format nil
+					     "~,,,2E"
+					     (bigfloat:bigfloat pi)))
+;; Fails because exponent is printed as "b0" instead of "b+0"
+(assert-equal "3.141592653589793b+0" (format nil "~E" (bigfloat:bigfloat pi)))
+
+
+;; These fail because too many digits are printed and because the
+;; scale factor isn't properly applied.
+(assert-equal ".03142d+2" (format nil "~9,5,,-1E" (bigfloat:bigfloat pi)))
+(assert-equal " 0.03142d+2" (format nil "~11,5,,-1E" (bigfloat:bigfloat pi)))
+(assert-equal "| 3141593.d-06|" (format nil "|~13,6,2,7E|" (bigfloat:bigfloat pi)))
+(assert-equal "0.314d+01" (format nil "~9,3,2,0,'%E" (bigfloat:bigfloat pi)))
+(assert-equal "+.003d+03" (format nil "~9,3,2,-2,'%@E" (bigfloat:bigfloat pi)))
+(assert-equal "+0.003d+03" (format nil "~10,3,2,-2,'%@E" (bigfloat:bigfloat pi)))
+(assert-equal "=====+0.003d+03" (format nil "~15,3,2,-2,'%,'=@E" (bigfloat:bigfloat pi)))
+(assert-equal "0.003d+03" (format nil "~9,3,2,-2,'%E" (bigfloat:bigfloat pi)))
+(assert-equal "%%%%%%%%" (format nil "~8,3,2,-2,'%@E" (bigfloat:bigfloat pi)))
+
+;; Works
+(assert-equal "0.0f+0" (format nil "~e" 0))
+
+;; Fails because exponent is printed as "b0" instead of "b+0'
+(assert-equal "0.0b+0" (format nil "~e" (bigfloat:bigfloat 0d0)))
+;; Fails because exponent is printed as "b0   " instead of "b+0000"
+(assert-equal "0.0b+0000" (format nil "~9,,4e" (bigfloat:bigfloat 0d0)))
+;; Fails because exponent is printed as "b4" isntead of "b+4"
+(assert-equal "1.2345678901234567b+4" (format nil "~E"
+					      (bigfloat:bigfloat 1.234567890123456789d4)))
+  
+;; Fails because exponent is printed as "b36" instead of "b+36"
+(assert-equal "1.32922799578492b+36" (format nil "~20E"
+					     (bigfloat:bigfloat (expt 2d0 120))))
+;; Fails because too many digits are printed and the exponent doesn't include "+".
+(assert-equal "       1.32922800b+36" (format nil "~21,8E"
+					      (bigfloat:bigfloat (expt 2d0 120))))
+|#
+
+
+;; Format bigfloats using ~F format. This is suitable as a ~// format.
+;;
+;; NOTE: This is a modified version of FORMAT-FIXED from CMUCL to
+;; support printing of bfloats.
+
+(defun format-f (stream number colonp atp
+		 &optional w d k overflowchar padchar)
+  (typecase number
+    (bigfloat
+     (maxima::bfloat-format-f stream (real-value number) colonp atp
+			      w d (or k 0)
+			      overflowchar
+			      (or padchar #\space)))
+    (complex-bigfloat
+     ;; FIXME: Do something better than this since this doesn't honor
+     ;; any of the parameters.
+     (princ number stream))
+    (otherwise
+     ;; We were given some other kind of object. Just use CL's normal
+     ;; ~F printer to print it.
+     (let ((f
+	     (with-output-to-string (s)
+	       ;; Construct a suitable ~F format string from the given
+	       ;; parameters.  First handle w,d,k.
+	       (write-string "~V,V,V," s)
+	       (if overflowchar
+		   (format s "'~C," overflowchar)
+		   (write-string "," s))
+	       (if (char= padchar #\space)
+		   (write-string "," s)
+		   (format s "'~C," padchar))
+	       (when colonp
+		 (write-char #\: s))
+	       (when atp
+		 (write-char #\@ s))
+	       (write-char #\F s))))
+       (format stream f w d k number)))))
+
+;; Format bigfloats using ~G format. This is suitable as a ~// format.
+;;
+;; NOTE: This is a modified version of FORMAT-GENERAL from CMUCL to
+;; support printing of bfloats.
+
+(defun format-g (stream number colonp atp
+		 &optional w d e k overflowchar padchar marker)
+  (typecase number
+    (bigfloat
+     (maxima::bfloat-format-g stream (real-value number) colonp atp
+			      w d e (or k 1) 
+			      overflowchar
+			      (or padchar #\space)
+			      (or marker #\b)))
+    (complex-bigfloat
+     ;; FIXME: Do something better than this since this doesn't honor
+     ;; any of the parameters.
+     (princ number stream))
+    (otherwise
+     ;; We were given some other kind of object. Just use CL's normal
+     ;; ~G printer to print it.
+     (let ((f
+	     (with-output-to-string (s)
+	       ;; Construct a suitable ~E format string from the given
+	       ;; parameters. First, handle w,d,e,k.
+	       (write-string "~V,V,V,V," s)
+	       (if overflowchar
+		   (format s "'~C," overflowchar)
+		   (write-string "," s))
+	       (if padchar
+		   (format s "'~C," padchar)
+		   (write-string "," s))
+	       (when marker
+		 (format s "'~C" marker))
+	       (when colonp
+		 (write-char #\: s))
+	       (when atp
+		 (write-char #\@ s))
+	       (write-char #\G s))))
+       (format stream f w d e k number)))))
+     
+     
