@@ -622,7 +622,7 @@
 		      wholepart parnumer varlist n))
 
 (defmfun $partfrac (exp var)
-  (cond ((and (not (atom exp)) (member (caar exp) '(mequal mlist $matrix) :test #'eq))
+  (cond ((mbagp exp)
 	 (cons (car exp) (mapcar #'(lambda (u) ($partfrac u var)) (cdr exp))))
 	((and (atom var) (not (among var exp))) exp)
 	(t (let (($savefactors t) (checkfactors ()) (varlist (list var))
@@ -651,30 +651,31 @@
 	((rzerop (car nc)) (cons (list (cdr nc) poly n) ans))
       (push (list (cdr nc) poly n) ans))))
 
-(defun partfrac (rat var &optional facdenom)
+(defun partfrac (rat var)
   (destructuring-let* (((wholepart frpart) (pdivide (car rat) (cdr rat)))
 		       ((num . denom) (ratqu frpart (cdr rat))))
-    (cond ((pzerop num) (cons wholepart nil))
-	  ((or (pcoefp denom) (pointergp var (car denom))) (cons rat nil))
-	  (t (destructuring-let (((content bpart) (oldcontent denom)))
-	       (do ((factor (or facdenom (pfactor bpart)) (cddr factor))
-		    (apart) (y) (parnumer))
-		   ((null factor) (cons wholepart parnumer))
-		 (cond
-		   ((zerop (pdegree (car factor) var)))
-		   (t (setq apart (pexpt (car factor) (cadr factor))
-			    bpart (pquotient bpart apart)
-			    y (bprog apart bpart)
-			    frpart (cdr (ratdivide (ratti num (cdr y) t)
-						   apart)))
-		      (push (list (ratqu frpart content)
-				  (car factor)
-				  (cadr factor))
-			    parnumer)
-		      (desetq (num . content)
-			      (cdr (ratdivide (ratqu (ratti num (car y) t)
-						     content)
-					      bpart)))))))))))
+    (cond
+      ((pzerop num) (cons wholepart nil))
+      ((or (pcoefp denom) (pointergp var (car denom))) (cons rat nil))
+      (t (destructuring-let (((content bpart) (oldcontent denom)))
+           (let (apart y parnumer)
+             (loop
+               for (factor multiplicity)
+                 on (pfactor bpart) by #'cddr
+               unless (zerop (pdegree factor var))
+                 do
+                    (setq apart (pexpt factor multiplicity)
+                          bpart (pquotient bpart apart)
+                          y (bprog apart bpart)
+                          frpart (cdr (ratdivide (ratti num (cdr y) t)
+                                                 apart)))
+                    (push (list (ratqu frpart content) factor multiplicity)
+                          parnumer)
+                    (desetq (num . content)
+                            (cdr (ratdivide (ratqu (ratti num (car y) t)
+                                                   content)
+                                            bpart))))
+             (cons wholepart parnumer)))))))
 
 (declare-top (unspecial exp f n ss v var xv y *chk *l *max *p
 			*res u* *x* *y*))
